Files
odfstudio/include
Luboš Luňák b26c34267c replace SfxPoolItem::LookupHashCode() with Lookup() (tdf#135215)
The LookupHashCode() way still loops over an array while calling
virtual functions for a type that is actually known. Overriding
instead a whole new Lookup() function that does the loop
avoids the virtual calls, allowing compiler optimizations such
as inlining, or class-specific optimizations like the hash code.
So this still improves performance with ScPatternAttr a bit,
for tdf#135215 it saves about 40% of load time, but this is
scraping the bottom of the barrel, as this is still a linear search
(the IsSortable() approach, if it worked, would be still 3x faster).

Change-Id: I8fe5f70cabb77e2f6619d169beee8a3b4da46213
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/130228
Tested-by: Jenkins
Reviewed-by: Luboš Luňák <l.lunak@collabora.com>
2022-02-21 12:29:49 +01:00
..
2022-02-03 08:16:03 +01:00
2021-11-04 15:26:14 +01:00
2022-01-03 06:49:18 +01:00
2022-01-20 17:34:36 +01:00
2022-02-09 19:17:29 +01:00
2021-10-01 20:58:11 +02:00
…
…
2021-11-05 13:59:10 +01:00
2022-01-08 15:32:56 +01:00
2021-10-11 11:37:04 +02:00
…
…
…
…